@@ -1,6 +1,7 @@
 package Mojo::Headers;
 use Mojo::Base -base;
 
+use Carp 'croak';
 use Mojo::Util 'monkey_patch';
 
 has max_line_size => sub { $ENV{MOJO_MAX_LINE_SIZE} || 8192 };
@@ -33,6 +34,8 @@ for my $header (keys %NAMES) {
 sub add {
   my ($self, $name) = (shift, shift);
 
+  tr/\x0d\x0a// and croak "Invalid characters in $name header" for @_;
+
   # Make sure we have a normal case entry for name
   my $key = lc $name;
   $self->{names}{$key} //= $name unless $NAMES{$key};
@@ -616,7 +619,6 @@ Get or replace current header value, shortcut for the C<Server> header.
 
 Get or replace current header value, shortcut for the C<Server-Timing> header
 from L<Server Timing|https://www.w3.org/TR/server-timing/>.
-Note that this method is EXPERIMENTAL and might change without warning!
 
 =head2 set_cookie
 
