@@ -53,8 +53,9 @@ sub every_param {
 sub merge {
   my $self = shift;
 
-  my @pairs = @_ == 1 ? @{shift->pairs} : @_;
-  while (my ($name, $value) = splice @pairs, 0, 2) {
+  my $merge = @_ == 1 ? shift->to_hash : {@_};
+  for my $name (sort keys %$merge) {
+    my $value = $merge->{$name};
     defined $value ? $self->param($name => $value) : $self->remove($name);
   }
 
@@ -247,7 +248,7 @@ Append parameters. Note that this method will normalize the parameters.
 
   my $params2 = $params->clone;
 
-Clone parameters.
+Return a new L<Mojo::Parameters> object cloned from these parameters.
 
 =head2 every_param
 
@@ -379,6 +380,6 @@ Alias for L</"to_string">.
 
 =head1 SEE ALSO
 
-L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
+L<Mojolicious>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
